/**
 * @file
 * VuoList_VuoFrameRequest C type definition.
 *
 * @copyright Copyright © 2012–2014 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoFrameRequest_H
#define VuoList_VuoFrameRequest_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoFrameRequest VuoList_VuoFrameRequest
 * A list of @ref VuoFrameRequest elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

/**
 * @typedef VuoList_VuoFrameRequest
 * A list of @ref VuoFrameRequest elements.
 */
#ifndef VuoList_VuoFrameRequest_TYPE_DEFINED
typedef void * VuoList_VuoFrameRequest;
#endif

/**
 * Creates a new list of @ref VuoFrameRequest elements.
 */
VuoList_VuoFrameRequest VuoListCreate_VuoFrameRequest(void);

/**
 * Returns the @ref VuoFrameRequest at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoFrameRequest VuoListGetValueAtIndex_VuoFrameRequest(const VuoList_VuoFrameRequest list, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoFrameRequest(VuoList_VuoFrameRequest list, const VuoFrameRequest value);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoFrameRequest(VuoList_VuoFrameRequest list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoFrameRequest(VuoList_VuoFrameRequest list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoFrameRequest(const VuoList_VuoFrameRequest list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoFrameRequest VuoList_VuoFrameRequest_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoFrameRequest_jsonFromValue(const VuoList_VuoFrameRequest value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoFrameRequest_summaryFromValue(const VuoList_VuoFrameRequest value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoFrameRequest VuoList_VuoFrameRequest_valueFromString(const char *str);
char * VuoList_VuoFrameRequest_stringFromValue(const VuoList_VuoFrameRequest value);
/// @}

/**
 * @}
 */

#endif
