/**
 * @file
 * VuoList_VuoOscMessage C type definition.
 *
 * @copyright Copyright © 2012–2014 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoOscMessage_H
#define VuoList_VuoOscMessage_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoOscMessage VuoList_VuoOscMessage
 * A list of @ref VuoOscMessage elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

/**
 * @typedef VuoList_VuoOscMessage
 * A list of @ref VuoOscMessage elements.
 */
#ifndef VuoList_VuoOscMessage_TYPE_DEFINED
typedef void * VuoList_VuoOscMessage;
#endif

/**
 * Creates a new list of @ref VuoOscMessage elements.
 */
VuoList_VuoOscMessage VuoListCreate_VuoOscMessage(void);

/**
 * Returns the @ref VuoOscMessage at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoOscMessage VuoListGetValueAtIndex_VuoOscMessage(const VuoList_VuoOscMessage list, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoOscMessage(VuoList_VuoOscMessage list, const VuoOscMessage value);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoOscMessage(VuoList_VuoOscMessage list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoOscMessage(VuoList_VuoOscMessage list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoOscMessage(const VuoList_VuoOscMessage list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoOscMessage VuoList_VuoOscMessage_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoOscMessage_jsonFromValue(const VuoList_VuoOscMessage value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoOscMessage_summaryFromValue(const VuoList_VuoOscMessage value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoOscMessage VuoList_VuoOscMessage_valueFromString(const char *str);
char * VuoList_VuoOscMessage_stringFromValue(const VuoList_VuoOscMessage value);
/// @}

/**
 * @}
 */

#endif
